@@ -17,3 +17,12 @@ def export_buttons(query=None):
         'exporters': exporters,
         'query': query,
     }
+
+
+@register.inclusion_tag('explorer/query_favorite_button.html')
+def query_favorite_button(query_id, is_favorite, extra_classes):
+    return {
+        'query_id': query_id,
+        'is_favorite': is_favorite,
+        'extra_classes': extra_classes
+    }
