@@ -15,7 +15,7 @@ from django.urls import reverse
 from explorer import app_settings
 from explorer.app_settings import EXPLORER_DEFAULT_CONNECTION as CONN
 from explorer.app_settings import EXPLORER_TOKEN
-from explorer.models import MSG_FAILED_BLACKLIST, Query, QueryLog
+from explorer.models import MSG_FAILED_BLACKLIST, Query, QueryFavorite, QueryLog
 from explorer.tests.factories import QueryLogFactory, SimpleQueryFactory
 from explorer.utils import user_can_see_query
 
@@ -202,6 +202,18 @@ class TestQueryDetailView(TestCase):
             self.assertTemplateUsed(resp, 'explorer/query.html')
             self.assertContains(resp, '6874')
 
+    def test_does_render_label_if_params_and_autorun(self):
+        with self.settings(EXPLORER_AUTORUN_QUERY_WITH_PARAMS=True):
+            reload_app_settings()
+            query = SimpleQueryFactory(sql='select 6870+4 where 1=$$myparam|test my param label:1$$;')
+            resp = self.client.get(
+                reverse(
+                    "query_detail", kwargs={'query_id': query.id}
+                )
+            )
+            self.assertTemplateUsed(resp, 'explorer/query.html')
+            self.assertContains(resp, 'test my param label')
+
     def test_admin_required(self):
         self.client.logout()
         query = SimpleQueryFactory()
@@ -825,3 +837,61 @@ class TestEmailQuery(TestCase):
             **{'HTTP_X_REQUESTED_WITH': 'XMLHttpRequest'}
         )
         self.assertEqual(mocked_execute.delay.call_count, 1)
+
+    def test_email_403(self):
+        query = SimpleQueryFactory()
+        url = reverse("email_csv_query", kwargs={'query_id': query.id})
+        response = self.client.post(
+            url,
+            data={},
+            **{'HTTP_X_REQUESTED_WITH': 'XMLHttpRequest'}
+        )
+        self.assertEqual(response.status_code, 403)
+
+    def test_email_no_xml_403(self):
+        query = SimpleQueryFactory()
+        url = reverse("email_csv_query", kwargs={'query_id': query.id})
+        response = self.client.post(
+            url,
+            data={},
+        )
+        self.assertEqual(response.status_code, 403)
+
+
+class TestQueryFavorites(TestCase):
+
+    def setUp(self):
+        self.user = User.objects.create_superuser(
+            'admin', 'admin@admin.com', 'pwd'
+        )
+        self.client.login(username='admin', password='pwd')
+        self.q = SimpleQueryFactory(title='query for x, y')
+        QueryFavorite.objects.create(user=self.user, query=self.q)
+
+    def test_returns_favorite_list(self):
+        resp = self.client.get(
+            reverse("query_favorites")
+        )
+        self.assertContains(resp, 'query for x, y')
+
+
+class TestQueryFavorite(TestCase):
+
+    def setUp(self):
+        self.user = User.objects.create_superuser(
+            'admin', 'admin@admin.com', 'pwd'
+        )
+        self.client.login(username='admin', password='pwd')
+        self.q = SimpleQueryFactory(title='query for x, y')
+
+    def test_toggle(self):
+        resp = self.client.post(
+            reverse("query_favorite",  args=(self.q.id,))
+        )
+        resp = json.loads(resp.content.decode('utf-8'))
+        self.assertTrue(resp['is_favorite'])
+        resp = self.client.post(
+            reverse("query_favorite",  args=(self.q.id,))
+        )
+        resp = json.loads(resp.content.decode('utf-8'))
+        self.assertFalse(resp['is_favorite'])
