@@ -1,8 +1,9 @@
-from django.urls import path, re_path
+from django.urls import path
 
 from explorer.views import (
     CreateQueryView, DeleteQueryView, DownloadFromSqlView, DownloadQueryView, EmailCsvQueryView, ListQueryLogView,
-    ListQueryView, PlayQueryView, QueryView, SchemaView, StreamQueryView, format_sql,
+    ListQueryView, PlayQueryView, QueryFavoritesView, QueryFavoriteView, QueryView, SchemaView, StreamQueryView,
+    format_sql,
 )
 
 
@@ -28,11 +29,13 @@ urlpatterns = [
     ),
     path('new/', CreateQueryView.as_view(), name='query_create'),
     path('play/', PlayQueryView.as_view(), name='explorer_playground'),
-    re_path(
-        r'schema/(?P<connection>.+)$', SchemaView.as_view(),
+    path(
+        'schema/<path:connection>', SchemaView.as_view(),
         name='explorer_schema'
     ),
     path('logs/', ListQueryLogView.as_view(), name='explorer_logs'),
     path('format/', format_sql, name='format_sql'),
+    path('favorites/', QueryFavoritesView.as_view(), name='query_favorites'),
+    path('favorite/<int:query_id>', QueryFavoriteView.as_view(), name='query_favorite'),
     path('', ListQueryView.as_view(), name='explorer_index'),
 ]
